window.Gleam.initSearch([{"doc":"dime","title":"dime","content":"# dime :coin:\n\n[![Package Version](https://img.shields.io/hexpm/v/dime)](https://hex.pm/packages/dime)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/dime/)\n\nA currency library based on the [ISO-4217 standard](https://en.wikipedia.org/wiki/ISO_4217) for Gleam.\n\n```sh\ngleam add dime@1\n```\n\n## Usage\n\n```gleam\nimport dime\n\npub fn main() {\n  // parse alpha-3 code\n  let gbp = dime.from_alpha_code(&quot;Gbp&quot;)\n\n  // parse numeric code\n  let huf = dime.from_numeric_code(&quot;348&quot;)\n\n  // use exported constants\n  let pln = dime.pln\n\n  gbp\n  |&gt; dime.display_name // &quot;Pound Sterling&quot;\n\n  gbp\n  |&gt; dime.symbol // &quot;£&quot;\n\n  huf\n  |&gt; dime.minor_units // 2\n\n  huf\n  |&gt; dime.alpha_code // &quot;HUF&quot;\n\n  pln\n  |&gt; dime.numeric_code // &quot;985&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/dime&gt;.\n\n## Development\n\n### Updating the ISO-4217 dataset\n\nTo update the [dataset](test/data/currencies.json) that is used to [test the ISO-4217 compliance](test/iso_4217_test.gleam#L32) of the library,\nfirst run the script below.\n\n```sh\n./scripts/extract_data.sh\n```\n\nIt downloads the latest currency dataset from the website of the standard&#39;s maintainer\nand converts it to a JSON file at `test/data/currencies.json`.\n\nThen, to validate the compliance of the library, run the test suite.\n\n```sh\ngleam test\n```\n\n## Roadmap\n\n- [ ] localisation?\n","url":"index.html"},{"doc":"dime","title":"Currency","content":"pub opaque type Currency\n\n\nSynonyms:\ndime.Currency\ndime Currency","url":"dime.html#Currency"},{"doc":"dime","title":"CurrencyCodeError","content":"pub type CurrencyCodeError {\n  InvalidFormat\n  UnrecognizedCode\n}\n Types of errors that can be encountered when parsing\n a currency from it&#39;s code (alpha or numeric).\n \nInvalidFormat\n\n\nUnrecognizedCode\n\n\nSynonyms:\ndime.CurrencyCodeError\ndime CurrencyCodeError","url":"dime.html#CurrencyCodeError"},{"doc":"dime","title":"aed","content":"pub const aed: Currency\n\nSynonyms:\ndime.aed\ndime aed","url":"dime.html#aed"},{"doc":"dime","title":"afn","content":"pub const afn: Currency\n\nSynonyms:\ndime.afn\ndime afn","url":"dime.html#afn"},{"doc":"dime","title":"all","content":"pub const all: Currency\n\nSynonyms:\ndime.all\ndime all","url":"dime.html#all"},{"doc":"dime","title":"amd","content":"pub const amd: Currency\n\nSynonyms:\ndime.amd\ndime amd","url":"dime.html#amd"},{"doc":"dime","title":"ang","content":"pub const ang: Currency\n\nSynonyms:\ndime.ang\ndime ang","url":"dime.html#ang"},{"doc":"dime","title":"aoa","content":"pub const aoa: Currency\n\nSynonyms:\ndime.aoa\ndime aoa","url":"dime.html#aoa"},{"doc":"dime","title":"ars","content":"pub const ars: Currency\n\nSynonyms:\ndime.ars\ndime ars","url":"dime.html#ars"},{"doc":"dime","title":"aud","content":"pub const aud: Currency\n\nSynonyms:\ndime.aud\ndime aud","url":"dime.html#aud"},{"doc":"dime","title":"awg","content":"pub const awg: Currency\n\nSynonyms:\ndime.awg\ndime awg","url":"dime.html#awg"},{"doc":"dime","title":"azn","content":"pub const azn: Currency\n\nSynonyms:\ndime.azn\ndime azn","url":"dime.html#azn"},{"doc":"dime","title":"bam","content":"pub const bam: Currency\n\nSynonyms:\ndime.bam\ndime bam","url":"dime.html#bam"},{"doc":"dime","title":"bbd","content":"pub const bbd: Currency\n\nSynonyms:\ndime.bbd\ndime bbd","url":"dime.html#bbd"},{"doc":"dime","title":"bdt","content":"pub const bdt: Currency\n\nSynonyms:\ndime.bdt\ndime bdt","url":"dime.html#bdt"},{"doc":"dime","title":"bgn","content":"pub const bgn: Currency\n\nSynonyms:\ndime.bgn\ndime bgn","url":"dime.html#bgn"},{"doc":"dime","title":"bhd","content":"pub const bhd: Currency\n\nSynonyms:\ndime.bhd\ndime bhd","url":"dime.html#bhd"},{"doc":"dime","title":"bif","content":"pub const bif: Currency\n\nSynonyms:\ndime.bif\ndime bif","url":"dime.html#bif"},{"doc":"dime","title":"bmd","content":"pub const bmd: Currency\n\nSynonyms:\ndime.bmd\ndime bmd","url":"dime.html#bmd"},{"doc":"dime","title":"bnd","content":"pub const bnd: Currency\n\nSynonyms:\ndime.bnd\ndime bnd","url":"dime.html#bnd"},{"doc":"dime","title":"bob","content":"pub const bob: Currency\n\nSynonyms:\ndime.bob\ndime bob","url":"dime.html#bob"},{"doc":"dime","title":"brl","content":"pub const brl: Currency\n\nSynonyms:\ndime.brl\ndime brl","url":"dime.html#brl"},{"doc":"dime","title":"bsd","content":"pub const bsd: Currency\n\nSynonyms:\ndime.bsd\ndime bsd","url":"dime.html#bsd"},{"doc":"dime","title":"btn","content":"pub const btn: Currency\n\nSynonyms:\ndime.btn\ndime btn","url":"dime.html#btn"},{"doc":"dime","title":"bwp","content":"pub const bwp: Currency\n\nSynonyms:\ndime.bwp\ndime bwp","url":"dime.html#bwp"},{"doc":"dime","title":"byn","content":"pub const byn: Currency\n\nSynonyms:\ndime.byn\ndime byn","url":"dime.html#byn"},{"doc":"dime","title":"bzd","content":"pub const bzd: Currency\n\nSynonyms:\ndime.bzd\ndime bzd","url":"dime.html#bzd"},{"doc":"dime","title":"cad","content":"pub const cad: Currency\n\nSynonyms:\ndime.cad\ndime cad","url":"dime.html#cad"},{"doc":"dime","title":"cdf","content":"pub const cdf: Currency\n\nSynonyms:\ndime.cdf\ndime cdf","url":"dime.html#cdf"},{"doc":"dime","title":"chf","content":"pub const chf: Currency\n\nSynonyms:\ndime.chf\ndime chf","url":"dime.html#chf"},{"doc":"dime","title":"clp","content":"pub const clp: Currency\n\nSynonyms:\ndime.clp\ndime clp","url":"dime.html#clp"},{"doc":"dime","title":"cny","content":"pub const cny: Currency\n\nSynonyms:\ndime.cny\ndime cny","url":"dime.html#cny"},{"doc":"dime","title":"cop","content":"pub const cop: Currency\n\nSynonyms:\ndime.cop\ndime cop","url":"dime.html#cop"},{"doc":"dime","title":"crc","content":"pub const crc: Currency\n\nSynonyms:\ndime.crc\ndime crc","url":"dime.html#crc"},{"doc":"dime","title":"cuc","content":"pub const cuc: Currency\n\nSynonyms:\ndime.cuc\ndime cuc","url":"dime.html#cuc"},{"doc":"dime","title":"cup","content":"pub const cup: Currency\n\nSynonyms:\ndime.cup\ndime cup","url":"dime.html#cup"},{"doc":"dime","title":"cve","content":"pub const cve: Currency\n\nSynonyms:\ndime.cve\ndime cve","url":"dime.html#cve"},{"doc":"dime","title":"czk","content":"pub const czk: Currency\n\nSynonyms:\ndime.czk\ndime czk","url":"dime.html#czk"},{"doc":"dime","title":"djf","content":"pub const djf: Currency\n\nSynonyms:\ndime.djf\ndime djf","url":"dime.html#djf"},{"doc":"dime","title":"dkk","content":"pub const dkk: Currency\n\nSynonyms:\ndime.dkk\ndime dkk","url":"dime.html#dkk"},{"doc":"dime","title":"dop","content":"pub const dop: Currency\n\nSynonyms:\ndime.dop\ndime dop","url":"dime.html#dop"},{"doc":"dime","title":"dzd","content":"pub const dzd: Currency\n\nSynonyms:\ndime.dzd\ndime dzd","url":"dime.html#dzd"},{"doc":"dime","title":"egp","content":"pub const egp: Currency\n\nSynonyms:\ndime.egp\ndime egp","url":"dime.html#egp"},{"doc":"dime","title":"ern","content":"pub const ern: Currency\n\nSynonyms:\ndime.ern\ndime ern","url":"dime.html#ern"},{"doc":"dime","title":"etb","content":"pub const etb: Currency\n\nSynonyms:\ndime.etb\ndime etb","url":"dime.html#etb"},{"doc":"dime","title":"eur","content":"pub const eur: Currency\n\nSynonyms:\ndime.eur\ndime eur","url":"dime.html#eur"},{"doc":"dime","title":"fjd","content":"pub const fjd: Currency\n\nSynonyms:\ndime.fjd\ndime fjd","url":"dime.html#fjd"},{"doc":"dime","title":"fkp","content":"pub const fkp: Currency\n\nSynonyms:\ndime.fkp\ndime fkp","url":"dime.html#fkp"},{"doc":"dime","title":"gbp","content":"pub const gbp: Currency\n\nSynonyms:\ndime.gbp\ndime gbp","url":"dime.html#gbp"},{"doc":"dime","title":"gel","content":"pub const gel: Currency\n\nSynonyms:\ndime.gel\ndime gel","url":"dime.html#gel"},{"doc":"dime","title":"ghs","content":"pub const ghs: Currency\n\nSynonyms:\ndime.ghs\ndime ghs","url":"dime.html#ghs"},{"doc":"dime","title":"gip","content":"pub const gip: Currency\n\nSynonyms:\ndime.gip\ndime gip","url":"dime.html#gip"},{"doc":"dime","title":"gmd","content":"pub const gmd: Currency\n\nSynonyms:\ndime.gmd\ndime gmd","url":"dime.html#gmd"},{"doc":"dime","title":"gnf","content":"pub const gnf: Currency\n\nSynonyms:\ndime.gnf\ndime gnf","url":"dime.html#gnf"},{"doc":"dime","title":"gtq","content":"pub const gtq: Currency\n\nSynonyms:\ndime.gtq\ndime gtq","url":"dime.html#gtq"},{"doc":"dime","title":"gyd","content":"pub const gyd: Currency\n\nSynonyms:\ndime.gyd\ndime gyd","url":"dime.html#gyd"},{"doc":"dime","title":"hkd","content":"pub const hkd: Currency\n\nSynonyms:\ndime.hkd\ndime hkd","url":"dime.html#hkd"},{"doc":"dime","title":"hnl","content":"pub const hnl: Currency\n\nSynonyms:\ndime.hnl\ndime hnl","url":"dime.html#hnl"},{"doc":"dime","title":"hrk","content":"pub const hrk: Currency\n\nSynonyms:\ndime.hrk\ndime hrk","url":"dime.html#hrk"},{"doc":"dime","title":"htg","content":"pub const htg: Currency\n\nSynonyms:\ndime.htg\ndime htg","url":"dime.html#htg"},{"doc":"dime","title":"huf","content":"pub const huf: Currency\n\nSynonyms:\ndime.huf\ndime huf","url":"dime.html#huf"},{"doc":"dime","title":"idr","content":"pub const idr: Currency\n\nSynonyms:\ndime.idr\ndime idr","url":"dime.html#idr"},{"doc":"dime","title":"ils","content":"pub const ils: Currency\n\nSynonyms:\ndime.ils\ndime ils","url":"dime.html#ils"},{"doc":"dime","title":"inr","content":"pub const inr: Currency\n\nSynonyms:\ndime.inr\ndime inr","url":"dime.html#inr"},{"doc":"dime","title":"iqd","content":"pub const iqd: Currency\n\nSynonyms:\ndime.iqd\ndime iqd","url":"dime.html#iqd"},{"doc":"dime","title":"irr","content":"pub const irr: Currency\n\nSynonyms:\ndime.irr\ndime irr","url":"dime.html#irr"},{"doc":"dime","title":"isk","content":"pub const isk: Currency\n\nSynonyms:\ndime.isk\ndime isk","url":"dime.html#isk"},{"doc":"dime","title":"jmd","content":"pub const jmd: Currency\n\nSynonyms:\ndime.jmd\ndime jmd","url":"dime.html#jmd"},{"doc":"dime","title":"jod","content":"pub const jod: Currency\n\nSynonyms:\ndime.jod\ndime jod","url":"dime.html#jod"},{"doc":"dime","title":"jpy","content":"pub const jpy: Currency\n\nSynonyms:\ndime.jpy\ndime jpy","url":"dime.html#jpy"},{"doc":"dime","title":"kes","content":"pub const kes: Currency\n\nSynonyms:\ndime.kes\ndime kes","url":"dime.html#kes"},{"doc":"dime","title":"kgs","content":"pub const kgs: Currency\n\nSynonyms:\ndime.kgs\ndime kgs","url":"dime.html#kgs"},{"doc":"dime","title":"khr","content":"pub const khr: Currency\n\nSynonyms:\ndime.khr\ndime khr","url":"dime.html#khr"},{"doc":"dime","title":"kmf","content":"pub const kmf: Currency\n\nSynonyms:\ndime.kmf\ndime kmf","url":"dime.html#kmf"},{"doc":"dime","title":"kpw","content":"pub const kpw: Currency\n\nSynonyms:\ndime.kpw\ndime kpw","url":"dime.html#kpw"},{"doc":"dime","title":"krw","content":"pub const krw: Currency\n\nSynonyms:\ndime.krw\ndime krw","url":"dime.html#krw"},{"doc":"dime","title":"kwd","content":"pub const kwd: Currency\n\nSynonyms:\ndime.kwd\ndime kwd","url":"dime.html#kwd"},{"doc":"dime","title":"kyd","content":"pub const kyd: Currency\n\nSynonyms:\ndime.kyd\ndime kyd","url":"dime.html#kyd"},{"doc":"dime","title":"kzt","content":"pub const kzt: Currency\n\nSynonyms:\ndime.kzt\ndime kzt","url":"dime.html#kzt"},{"doc":"dime","title":"lak","content":"pub const lak: Currency\n\nSynonyms:\ndime.lak\ndime lak","url":"dime.html#lak"},{"doc":"dime","title":"lbp","content":"pub const lbp: Currency\n\nSynonyms:\ndime.lbp\ndime lbp","url":"dime.html#lbp"},{"doc":"dime","title":"lkr","content":"pub const lkr: Currency\n\nSynonyms:\ndime.lkr\ndime lkr","url":"dime.html#lkr"},{"doc":"dime","title":"lrd","content":"pub const lrd: Currency\n\nSynonyms:\ndime.lrd\ndime lrd","url":"dime.html#lrd"},{"doc":"dime","title":"lsl","content":"pub const lsl: Currency\n\nSynonyms:\ndime.lsl\ndime lsl","url":"dime.html#lsl"},{"doc":"dime","title":"lyd","content":"pub const lyd: Currency\n\nSynonyms:\ndime.lyd\ndime lyd","url":"dime.html#lyd"},{"doc":"dime","title":"mad","content":"pub const mad: Currency\n\nSynonyms:\ndime.mad\ndime mad","url":"dime.html#mad"},{"doc":"dime","title":"mdl","content":"pub const mdl: Currency\n\nSynonyms:\ndime.mdl\ndime mdl","url":"dime.html#mdl"},{"doc":"dime","title":"mga","content":"pub const mga: Currency\n\nSynonyms:\ndime.mga\ndime mga","url":"dime.html#mga"},{"doc":"dime","title":"mkd","content":"pub const mkd: Currency\n\nSynonyms:\ndime.mkd\ndime mkd","url":"dime.html#mkd"},{"doc":"dime","title":"mmk","content":"pub const mmk: Currency\n\nSynonyms:\ndime.mmk\ndime mmk","url":"dime.html#mmk"},{"doc":"dime","title":"mnt","content":"pub const mnt: Currency\n\nSynonyms:\ndime.mnt\ndime mnt","url":"dime.html#mnt"},{"doc":"dime","title":"mop","content":"pub const mop: Currency\n\nSynonyms:\ndime.mop\ndime mop","url":"dime.html#mop"},{"doc":"dime","title":"mru","content":"pub const mru: Currency\n\nSynonyms:\ndime.mru\ndime mru","url":"dime.html#mru"},{"doc":"dime","title":"mur","content":"pub const mur: Currency\n\nSynonyms:\ndime.mur\ndime mur","url":"dime.html#mur"},{"doc":"dime","title":"mvr","content":"pub const mvr: Currency\n\nSynonyms:\ndime.mvr\ndime mvr","url":"dime.html#mvr"},{"doc":"dime","title":"mwk","content":"pub const mwk: Currency\n\nSynonyms:\ndime.mwk\ndime mwk","url":"dime.html#mwk"},{"doc":"dime","title":"mxn","content":"pub const mxn: Currency\n\nSynonyms:\ndime.mxn\ndime mxn","url":"dime.html#mxn"},{"doc":"dime","title":"myr","content":"pub const myr: Currency\n\nSynonyms:\ndime.myr\ndime myr","url":"dime.html#myr"},{"doc":"dime","title":"mzn","content":"pub const mzn: Currency\n\nSynonyms:\ndime.mzn\ndime mzn","url":"dime.html#mzn"},{"doc":"dime","title":"nad","content":"pub const nad: Currency\n\nSynonyms:\ndime.nad\ndime nad","url":"dime.html#nad"},{"doc":"dime","title":"ngn","content":"pub const ngn: Currency\n\nSynonyms:\ndime.ngn\ndime ngn","url":"dime.html#ngn"},{"doc":"dime","title":"nio","content":"pub const nio: Currency\n\nSynonyms:\ndime.nio\ndime nio","url":"dime.html#nio"},{"doc":"dime","title":"nok","content":"pub const nok: Currency\n\nSynonyms:\ndime.nok\ndime nok","url":"dime.html#nok"},{"doc":"dime","title":"npr","content":"pub const npr: Currency\n\nSynonyms:\ndime.npr\ndime npr","url":"dime.html#npr"},{"doc":"dime","title":"nzd","content":"pub const nzd: Currency\n\nSynonyms:\ndime.nzd\ndime nzd","url":"dime.html#nzd"},{"doc":"dime","title":"omr","content":"pub const omr: Currency\n\nSynonyms:\ndime.omr\ndime omr","url":"dime.html#omr"},{"doc":"dime","title":"pab","content":"pub const pab: Currency\n\nSynonyms:\ndime.pab\ndime pab","url":"dime.html#pab"},{"doc":"dime","title":"pen","content":"pub const pen: Currency\n\nSynonyms:\ndime.pen\ndime pen","url":"dime.html#pen"},{"doc":"dime","title":"pgk","content":"pub const pgk: Currency\n\nSynonyms:\ndime.pgk\ndime pgk","url":"dime.html#pgk"},{"doc":"dime","title":"php","content":"pub const php: Currency\n\nSynonyms:\ndime.php\ndime php","url":"dime.html#php"},{"doc":"dime","title":"pkr","content":"pub const pkr: Currency\n\nSynonyms:\ndime.pkr\ndime pkr","url":"dime.html#pkr"},{"doc":"dime","title":"pln","content":"pub const pln: Currency\n\nSynonyms:\ndime.pln\ndime pln","url":"dime.html#pln"},{"doc":"dime","title":"pyg","content":"pub const pyg: Currency\n\nSynonyms:\ndime.pyg\ndime pyg","url":"dime.html#pyg"},{"doc":"dime","title":"qar","content":"pub const qar: Currency\n\nSynonyms:\ndime.qar\ndime qar","url":"dime.html#qar"},{"doc":"dime","title":"ron","content":"pub const ron: Currency\n\nSynonyms:\ndime.ron\ndime ron","url":"dime.html#ron"},{"doc":"dime","title":"rsd","content":"pub const rsd: Currency\n\nSynonyms:\ndime.rsd\ndime rsd","url":"dime.html#rsd"},{"doc":"dime","title":"rub","content":"pub const rub: Currency\n\nSynonyms:\ndime.rub\ndime rub","url":"dime.html#rub"},{"doc":"dime","title":"rwf","content":"pub const rwf: Currency\n\nSynonyms:\ndime.rwf\ndime rwf","url":"dime.html#rwf"},{"doc":"dime","title":"sar","content":"pub const sar: Currency\n\nSynonyms:\ndime.sar\ndime sar","url":"dime.html#sar"},{"doc":"dime","title":"sbd","content":"pub const sbd: Currency\n\nSynonyms:\ndime.sbd\ndime sbd","url":"dime.html#sbd"},{"doc":"dime","title":"scr","content":"pub const scr: Currency\n\nSynonyms:\ndime.scr\ndime scr","url":"dime.html#scr"},{"doc":"dime","title":"sdg","content":"pub const sdg: Currency\n\nSynonyms:\ndime.sdg\ndime sdg","url":"dime.html#sdg"},{"doc":"dime","title":"sek","content":"pub const sek: Currency\n\nSynonyms:\ndime.sek\ndime sek","url":"dime.html#sek"},{"doc":"dime","title":"sgd","content":"pub const sgd: Currency\n\nSynonyms:\ndime.sgd\ndime sgd","url":"dime.html#sgd"},{"doc":"dime","title":"shp","content":"pub const shp: Currency\n\nSynonyms:\ndime.shp\ndime shp","url":"dime.html#shp"},{"doc":"dime","title":"sle","content":"pub const sle: Currency\n\nSynonyms:\ndime.sle\ndime sle","url":"dime.html#sle"},{"doc":"dime","title":"sos","content":"pub const sos: Currency\n\nSynonyms:\ndime.sos\ndime sos","url":"dime.html#sos"},{"doc":"dime","title":"srd","content":"pub const srd: Currency\n\nSynonyms:\ndime.srd\ndime srd","url":"dime.html#srd"},{"doc":"dime","title":"ssp","content":"pub const ssp: Currency\n\nSynonyms:\ndime.ssp\ndime ssp","url":"dime.html#ssp"},{"doc":"dime","title":"stn","content":"pub const stn: Currency\n\nSynonyms:\ndime.stn\ndime stn","url":"dime.html#stn"},{"doc":"dime","title":"svc","content":"pub const svc: Currency\n\nSynonyms:\ndime.svc\ndime svc","url":"dime.html#svc"},{"doc":"dime","title":"syp","content":"pub const syp: Currency\n\nSynonyms:\ndime.syp\ndime syp","url":"dime.html#syp"},{"doc":"dime","title":"szl","content":"pub const szl: Currency\n\nSynonyms:\ndime.szl\ndime szl","url":"dime.html#szl"},{"doc":"dime","title":"thb","content":"pub const thb: Currency\n\nSynonyms:\ndime.thb\ndime thb","url":"dime.html#thb"},{"doc":"dime","title":"tjs","content":"pub const tjs: Currency\n\nSynonyms:\ndime.tjs\ndime tjs","url":"dime.html#tjs"},{"doc":"dime","title":"tmt","content":"pub const tmt: Currency\n\nSynonyms:\ndime.tmt\ndime tmt","url":"dime.html#tmt"},{"doc":"dime","title":"tnd","content":"pub const tnd: Currency\n\nSynonyms:\ndime.tnd\ndime tnd","url":"dime.html#tnd"},{"doc":"dime","title":"top","content":"pub const top: Currency\n\nSynonyms:\ndime.top\ndime top","url":"dime.html#top"},{"doc":"dime","title":"try","content":"pub const try: Currency\n\nSynonyms:\ndime.try\ndime try","url":"dime.html#try"},{"doc":"dime","title":"ttd","content":"pub const ttd: Currency\n\nSynonyms:\ndime.ttd\ndime ttd","url":"dime.html#ttd"},{"doc":"dime","title":"twd","content":"pub const twd: Currency\n\nSynonyms:\ndime.twd\ndime twd","url":"dime.html#twd"},{"doc":"dime","title":"tzs","content":"pub const tzs: Currency\n\nSynonyms:\ndime.tzs\ndime tzs","url":"dime.html#tzs"},{"doc":"dime","title":"uah","content":"pub const uah: Currency\n\nSynonyms:\ndime.uah\ndime uah","url":"dime.html#uah"},{"doc":"dime","title":"ugx","content":"pub const ugx: Currency\n\nSynonyms:\ndime.ugx\ndime ugx","url":"dime.html#ugx"},{"doc":"dime","title":"usd","content":"pub const usd: Currency\n\nSynonyms:\ndime.usd\ndime usd","url":"dime.html#usd"},{"doc":"dime","title":"uyu","content":"pub const uyu: Currency\n\nSynonyms:\ndime.uyu\ndime uyu","url":"dime.html#uyu"},{"doc":"dime","title":"uyw","content":"pub const uyw: Currency\n\nSynonyms:\ndime.uyw\ndime uyw","url":"dime.html#uyw"},{"doc":"dime","title":"uzs","content":"pub const uzs: Currency\n\nSynonyms:\ndime.uzs\ndime uzs","url":"dime.html#uzs"},{"doc":"dime","title":"ved","content":"pub const ved: Currency\n\nSynonyms:\ndime.ved\ndime ved","url":"dime.html#ved"},{"doc":"dime","title":"ves","content":"pub const ves: Currency\n\nSynonyms:\ndime.ves\ndime ves","url":"dime.html#ves"},{"doc":"dime","title":"vnd","content":"pub const vnd: Currency\n\nSynonyms:\ndime.vnd\ndime vnd","url":"dime.html#vnd"},{"doc":"dime","title":"vuv","content":"pub const vuv: Currency\n\nSynonyms:\ndime.vuv\ndime vuv","url":"dime.html#vuv"},{"doc":"dime","title":"wst","content":"pub const wst: Currency\n\nSynonyms:\ndime.wst\ndime wst","url":"dime.html#wst"},{"doc":"dime","title":"xaf","content":"pub const xaf: Currency\n\nSynonyms:\ndime.xaf\ndime xaf","url":"dime.html#xaf"},{"doc":"dime","title":"xcd","content":"pub const xcd: Currency\n\nSynonyms:\ndime.xcd\ndime xcd","url":"dime.html#xcd"},{"doc":"dime","title":"xof","content":"pub const xof: Currency\n\nSynonyms:\ndime.xof\ndime xof","url":"dime.html#xof"},{"doc":"dime","title":"xpf","content":"pub const xpf: Currency\n\nSynonyms:\ndime.xpf\ndime xpf","url":"dime.html#xpf"},{"doc":"dime","title":"yer","content":"pub const yer: Currency\n\nSynonyms:\ndime.yer\ndime yer","url":"dime.html#yer"},{"doc":"dime","title":"zar","content":"pub const zar: Currency\n\nSynonyms:\ndime.zar\ndime zar","url":"dime.html#zar"},{"doc":"dime","title":"zmw","content":"pub const zmw: Currency\n\nSynonyms:\ndime.zmw\ndime zmw","url":"dime.html#zmw"},{"doc":"dime","title":"zwg","content":"pub const zwg: Currency\n\nSynonyms:\ndime.zwg\ndime zwg","url":"dime.html#zwg"},{"doc":"dime","title":"alpha_code","content":"pub fn alpha_code(currency: Currency) -&gt; String\n Get the 3 character alphabetic code for the currency.\n \nSynonyms:\ndime.alpha_code\ndime alpha_code","url":"dime.html#alpha_code"},{"doc":"dime","title":"display_name","content":"pub fn display_name(currency: Currency) -&gt; String\n Get the display name of the currency in English.\n \nSynonyms:\ndime.display_name\ndime display_name","url":"dime.html#display_name"},{"doc":"dime","title":"from_alpha_code","content":"pub fn from_alpha_code(\n  currency_code: String,\n) -&gt; Result(Currency, CurrencyCodeError)\n Try and retrieve a currency by it&#39;s 3 character alphabetic code.\n \nSynonyms:\ndime.from_alpha_code\ndime from_alpha_code","url":"dime.html#from_alpha_code"},{"doc":"dime","title":"from_numeric_code","content":"pub fn from_numeric_code(\n  currency_code: String,\n) -&gt; Result(Currency, CurrencyCodeError)\n Try and retrieve a currency by it&#39;s 3 character numeric code.\n \nSynonyms:\ndime.from_numeric_code\ndime from_numeric_code","url":"dime.html#from_numeric_code"},{"doc":"dime","title":"known_currencies","content":"pub fn known_currencies() -&gt; List(Currency)\n Retrieve the list of all the currencies known to this library.\n \nSynonyms:\ndime.known_currencies\ndime known_currencies","url":"dime.html#known_currencies"},{"doc":"dime","title":"minor_units","content":"pub fn minor_units(currency: Currency) -&gt; Int\n The decimal relationship between the currency and\n it&#39;s minor unit, e.g. euro and euro cent.\n \n 1, 2 and 3 signify a ratio of 10:1, 100:1 and 1000:1\n respectively.\n \nSynonyms:\ndime.minor_units\ndime minor_units","url":"dime.html#minor_units"},{"doc":"dime","title":"numeric_code","content":"pub fn numeric_code(currency: Currency) -&gt; String\n Get the 3 character numeric code for the currency.\n \nSynonyms:\ndime.numeric_code\ndime numeric_code","url":"dime.html#numeric_code"},{"doc":"dime","title":"symbol","content":"pub fn symbol(currency: Currency) -&gt; String\n Get the graphical symbol used as a shorthand \n representation of the specific currency unit.\n \nSynonyms:\ndime.symbol\ndime symbol","url":"dime.html#symbol"},{"doc":"dime","title":"dime","content":"","url":"dime.html"}]);